@@ -2,9 +2,9 @@
 # -*- coding: utf-8 -*-
 #
 #	Copyright (C) 2003-2010 Daniel Naber, Lutz Haseloff
-#	Copyright (C) 2013-2014 Mechtilde Stehmann
+#	Copyright (C) 2013-2015 Mechtilde Stehmann
 #
-#	Copyright (C) 2013-2014 for the gettext integration: Dr. Michael Stehmann
+#	Copyright (C) 2013-2015 for the gettext integration: Dr. Michael Stehmann
 #
 #	This program is free software; you can redistribute it and/or
 #	modify it under the terms of the GNU General Public License
@@ -377,9 +377,9 @@ class Application(object):
 				self.ooo_count = self.ooo_count + 1
 
 		except zipfile.BadZipfile as err:
-			print(_("Warning: Supposed ZIP file ") + filename + _("could not be opened: ") + err)
+			print(_("Warning: Supposed ZIP file ") + filename + _("could not be opened: ") + str(err))
 		except IOError as err:
-			print(_("Warning: File ") + filename + _("could not be opened: ") + err)
+			print(_("Warning: File ") + filename + _("could not be opened: ") + str(err))
 		return None
 		
 	def startSearch(self, event=None):
@@ -427,7 +427,7 @@ class Application(object):
 			dir_content = os.listdir(directory)
 			dir_content.sort(key=str.lower) 
 		except OSError as err:
-			print(_("Warning: ") + directory + (": ") + err)
+			print(_("Warning: ") + directory + (": ") + str(err))
 			return
 		except UnicodeError as err:
 			print(_("Warning: Unicode problem with directory name..."))
@@ -463,7 +463,7 @@ class Application(object):
 		savestring = _("Search path:") + " " + self.search_path.get() + "\n"
 		savestring = savestring + _("Search terms:") + " " + self.search_query.get() + "\n"
 		savestring = savestring + _("Mode:") + " " + self.mode_button["text"] + "\n\n"
-		savestring = savestring + _("Results:") + "\n" + self.savestring
+		savestring = savestring + _("Matches:") + "\n" + self.savestring
 		fo = tkinter.filedialog.asksaveasfile()
 		fo.write(savestring)
 		self.stopped = 1
@@ -555,7 +555,7 @@ class TranslationIntegration(object):
 
 if __name__ == "__main__":
 
-	version = "0.8.0"
+	version = "0.8.1"
 	loookversion = "loook-" + version
 	
 	g = TranslationIntegration(loookversion) 
